<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Kits Documentation

- **[artifact-path-transformation.md](artifact-path-transformation.md)** — debugging kit artifact path mismatches, modifying kit artifact installation logic, understanding why doc artifacts have different path handling, fixing compare_artifact_lists or check_artifact_sync
- **[artifact-synchronization.md](artifact-synchronization.md)** — adding commands to kits, removing kit commands, test_check_command_perfect_sync fails, kit manifest validation errors
- **[at-reference-resolution.md](at-reference-resolution.md)** — erk md check fails with @ reference errors in kit sources, wondering why kit-md-check excludes --check-links, writing @ references in kit source files, understanding kit source vs installed artifact paths
- **[cli-command-development.md](cli-command-development.md)** — adding new kit CLI commands, creating kit commands from scratch, understanding kit command file structure
- **[cli-commands.md](cli-commands.md)** — creating kit CLI commands, understanding Python/LLM boundary, implementing kit command patterns
- **[code-architecture.md](code-architecture.md)** — understanding kit code structure, creating kit CLI commands, organizing kit Python code
- **[creating-kit-scripts.md](creating-kit-scripts.md)** — creating kit scripts, adding Python CLI commands to kits, testing kit script commands
- **[dependency-injection.md](dependency-injection.md)** — writing kit CLI commands, testing kit CLI commands, using DotAgentContext
- **[artifact-management.md](artifact-management.md)** — adding artifacts to kits, fixing kit-check errors, troubleshooting kit sync, kit sync says up to date but artifacts missing
- **[kit-check.md](kit-check.md)** — validating kit configuration, debugging missing artifacts, kit-check errors
- **[doc-installation.md](doc-installation.md)** — understanding where kit documentation gets installed, adding documentation to a kit, wondering why docs are in .erk instead of .claude, creating @ references to kit documentation
- **[push-down-pattern.md](push-down-pattern.md)** — deciding what belongs in kit CLI vs agent markdown, moving bash logic from agent prompts to Python, reducing token usage in agent prompts, designing kit CLI commands for agents
- **[registry-discovery.md](registry-discovery.md)** — kit not showing in search, debugging kit discovery, understanding registry.yaml
